@@ -30,7 +30,6 @@ class Cash:
         response = requests.get(url, headers=headers)
         return response.json()
 
-
     def transaction(self):
         return self.tx
 
@@ -44,18 +43,17 @@ class Account:
 
     def login(self, jaye_account,password):
         # 로그인 중이라면 중복 로그인 방지
-        if self.is_login == True:
+        if self.is_login:
             print('접속 중인 기존 계정을 로그아웃하십시오')
             return None
 
         # 로그 아웃 상태라면 로그인 실행
         url = BASE_URL_ACCOUNT + '/accounts/login/'
-        data = {"jaye_account":jaye_account,"password":password}
+        data = {"jaye_account": jaye_account, "password": password}
         # 로그인 실패 시 return으로 함수 실행 중단
 
-        headers = {"accept" : 'application/json', 'content-type' : 'application/json;charset=UTF-8'}
-        response= requests.post(url,data = json.dumps(data),headers = headers)
-
+        headers = {"accept": 'application/json', 'content-type': 'application/json;charset=UTF-8'}
+        response = requests.post(url, data=json.dumps(data), headers=headers)
 
         self.myinfo = response.json()
 
@@ -65,8 +63,8 @@ class Account:
         # STRATEGIES from settings.py
 
         url = BASE_URL_PUBLIC + '/trade/strategies/'
-        headers = {'Authorization' : user_token}
-        response = requests.get(url,headers = headers)
+        headers = {'Authorization': user_token}
+        response = requests.get(url, headers=headers)
         STRATEGIES = response.json()
 
         for i in STRATEGIES:
@@ -78,10 +76,9 @@ class Account:
 
         # insert token
         self.cash.token = user_token
-        self.jaye.Analysis.token = user_token
+        self.jaye.analysis.token = user_token
         self.is_login = True
 
-
     def logout(self):
         url = BASE_URL_ACCOUNT + '/accounts/logout/'
         response = requests.post(url)
@@ -115,7 +112,7 @@ class Analysis:
 
         return df_assets
 
-    def factor_history(self,symbol,start,end):
+    def factor_history(self, symbol, start, end):
         url = BASE_URL_PUBLIC + f"/analysis/factor-history/?company={symbol}&from={start}&to={end}"
         headers = {'Authorization': self.token}
         response = requests.get(url, headers=headers)
@@ -145,7 +142,7 @@ class Analysis:
 
         return df_factors
 
-    def fundamental(self,symbol,start,end):
+    def fundamental(self, symbol, start, end):
         url = BASE_URL_PUBLIC + f"/analysis/fundamental/?company={symbol}&from={start}&to={end}"
         headers = {'Authorization': self.token}
         response = requests.get(url, headers=headers)
@@ -172,7 +169,6 @@ class Analysis:
         except:
             print(response.json())
             return None
-
         return df_market
 
 
@@ -184,12 +180,11 @@ class Strategy:
     def returns(self, start,end):
         headers = {"Authorization" : self.token}
         url = BASE_URL_PUBLIC + f"/performance/return/?strategy%20name={self.strategy_name}&from={start}&to={end}"
-        response = requests.get(url,headers = headers)
+        response = requests.get(url, headers=headers)
         df_returns = pd.DataFrame(response.json())
-
         return df_returns
 
-    def stats(self,start,end,rolling=255,risk_free_rate=0,base_index='INDEX-KRX-KOSPI-KOSPI'):
+    def stats(self, start, end, rolling=255, risk_free_rate=0, base_index='INDEX-KRX-KOSPI-KOSPI'):
         rolling = str(rolling)
         risk_free_rate = str(risk_free_rate)
         base_index = str(base_index)
@@ -198,7 +193,6 @@ class Strategy:
         url = BASE_URL_PUBLIC + f"/performance/stats/?strategy%20name={self.strategy_name}&from={start}&to={end}&rolling={rolling}&risk_free_rate={risk_free_rate}&base_index={base_index}"
         response = requests.get(url, headers=headers)
         df_returns = pd.DataFrame(response.json())
-
         return df_returns
 
     def asset_allocation(self, start, end):
