@@ -1,9 +1,5 @@
 from rich.console import Console
 
 CONSOLE = Console()
-JAYE_ACCOUNT = ""
-PASSWORD = ""
 BASE_URL_ACCOUNT = "https://account.jaye.world"
-# BASE_URL_PUBLIC = "http://127.0.0.1:8000"
 BASE_URL_PUBLIC = "https://qaas.jaye.world"
-TOKEN = ""
\ No newline at end of file
